nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Misc2Set

Struct Misc2Set 

#[repr(transparent)]
pub struct Misc2Set(pub u32);
Miscellaneous Control Register

Tuple Fields

0: u32

Implementations

Source

impl Misc2Set

pub const fn reg0_bo_offset(&self) -> Misc2SetReg0BoOffset

This field defines the brown out voltage offset for the CORE power domain

pub const fn set_reg0_bo_offset(&mut self, val: Misc2SetReg0BoOffset)

This field defines the brown out voltage offset for the CORE power domain

pub const fn reg0_bo_status(&self) -> bool

Reg0 brownout status bit.

pub const fn set_reg0_bo_status(&mut self, val: bool)

Reg0 brownout status bit.

pub const fn reg0_enable_bo(&self) -> bool

Enables the brownout detection.

pub const fn set_reg0_enable_bo(&mut self, val: bool)

Enables the brownout detection.

pub const fn pll3_disable(&self) -> bool

Default value of “0”

pub const fn set_pll3_disable(&mut self, val: bool)

Default value of “0”

pub const fn reg1_bo_offset(&self) -> Misc2SetReg1BoOffset

This field defines the brown out voltage offset for the xPU power domain

pub const fn set_reg1_bo_offset(&mut self, val: Misc2SetReg1BoOffset)

This field defines the brown out voltage offset for the xPU power domain

pub const fn reg1_bo_status(&self) -> bool

Reg1 brownout status bit.

pub const fn set_reg1_bo_status(&mut self, val: bool)

Reg1 brownout status bit.

pub const fn reg1_enable_bo(&self) -> bool

Enables the brownout detection.

pub const fn set_reg1_enable_bo(&mut self, val: bool)

Enables the brownout detection.

pub const fn audio_div_lsb(&self) -> Misc2SetAudioDivLsb

LSB of Post-divider for Audio PLL

pub const fn set_audio_div_lsb(&mut self, val: Misc2SetAudioDivLsb)

LSB of Post-divider for Audio PLL

pub const fn reg2_bo_offset(&self) -> Misc2SetReg2BoOffset

This field defines the brown out voltage offset for the xPU power domain

pub const fn set_reg2_bo_offset(&mut self, val: Misc2SetReg2BoOffset)

This field defines the brown out voltage offset for the xPU power domain

pub const fn reg2_bo_status(&self) -> bool

Reg2 brownout status bit.

pub const fn set_reg2_bo_status(&mut self, val: bool)

Reg2 brownout status bit.

pub const fn reg2_enable_bo(&self) -> bool

Enables the brownout detection.

pub const fn set_reg2_enable_bo(&mut self, val: bool)

Enables the brownout detection.

pub const fn reg2_ok(&self) -> bool

Signals that the voltage is above the brownout level for the SOC supply

pub const fn set_reg2_ok(&mut self, val: bool)

Signals that the voltage is above the brownout level for the SOC supply

pub const fn audio_div_msb(&self) -> Misc2SetAudioDivMsb

MSB of Post-divider for Audio PLL

pub const fn set_audio_div_msb(&mut self, val: Misc2SetAudioDivMsb)

MSB of Post-divider for Audio PLL

pub const fn reg0_step_time(&self) -> Misc2SetReg0StepTime

Number of clock periods (24MHz clock).

pub const fn set_reg0_step_time(&mut self, val: Misc2SetReg0StepTime)

Number of clock periods (24MHz clock).

pub const fn reg1_step_time(&self) -> Misc2SetReg1StepTime

Number of clock periods (24MHz clock).

pub const fn set_reg1_step_time(&mut self, val: Misc2SetReg1StepTime)

Number of clock periods (24MHz clock).

pub const fn reg2_step_time(&self) -> Misc2SetReg2StepTime

Number of clock periods (24MHz clock).

pub const fn set_reg2_step_time(&mut self, val: Misc2SetReg2StepTime)

Number of clock periods (24MHz clock).

pub const fn video_div(&self) -> Misc2SetVideoDiv

Post-divider for video

pub const fn set_video_div(&mut self, val: Misc2SetVideoDiv)

Post-divider for video