nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Reg1p1Tog

Struct Reg1p1Tog 

#[repr(transparent)]
pub struct Reg1p1Tog(pub u32);
Regulator 1P1 Register

Tuple Fields

0: u32

Implementations

Source

impl Reg1p1Tog

pub const fn enable_linreg(&self) -> bool

Control bit to enable the regulator output.

pub const fn set_enable_linreg(&mut self, val: bool)

Control bit to enable the regulator output.

pub const fn enable_bo(&self) -> bool

Control bit to enable the brownout circuitry in the regulator.

pub const fn set_enable_bo(&mut self, val: bool)

Control bit to enable the brownout circuitry in the regulator.

pub const fn enable_ilimit(&self) -> bool

Control bit to enable the current-limit circuitry in the regulator.

pub const fn set_enable_ilimit(&mut self, val: bool)

Control bit to enable the current-limit circuitry in the regulator.

pub const fn enable_pulldown(&self) -> bool

Control bit to enable the pull-down circuitry in the regulator

pub const fn set_enable_pulldown(&mut self, val: bool)

Control bit to enable the pull-down circuitry in the regulator

pub const fn bo_offset(&self) -> u8

Control bits to adjust the regulator brownout offset voltage in 25mV steps

pub const fn set_bo_offset(&mut self, val: u8)

Control bits to adjust the regulator brownout offset voltage in 25mV steps

pub const fn output_trg(&self) -> Reg1p1TogOutputTrg

Control bits to adjust the regulator output voltage

pub const fn set_output_trg(&mut self, val: Reg1p1TogOutputTrg)

Control bits to adjust the regulator output voltage

pub const fn bo_vdd1p1(&self) -> bool

Status bit that signals when a brownout is detected on the regulator output.

pub const fn set_bo_vdd1p1(&mut self, val: bool)

Status bit that signals when a brownout is detected on the regulator output.

pub const fn ok_vdd1p1(&self) -> bool

Status bit that signals when the regulator output is ok. 1 = regulator output > brownout target

pub const fn set_ok_vdd1p1(&mut self, val: bool)

Status bit that signals when the regulator output is ok. 1 = regulator output > brownout target

pub const fn enable_weak_linreg(&self) -> bool

Enables the weak 1p1 regulator

pub const fn set_enable_weak_linreg(&mut self, val: bool)

Enables the weak 1p1 regulator

pub const fn selref_weak_linreg(&self) -> Reg1p1TogSelrefWeakLinreg

Selects the source for the reference voltage of the weak 1p1 regulator.

pub const fn set_selref_weak_linreg(&mut self, val: Reg1p1TogSelrefWeakLinreg)

Selects the source for the reference voltage of the weak 1p1 regulator.