nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Reg2p5Tog

Struct Reg2p5Tog 

#[repr(transparent)]
pub struct Reg2p5Tog(pub u32);
Regulator 2P5 Register

Tuple Fields

0: u32

Implementations

Source

impl Reg2p5Tog

pub const fn enable_linreg(&self) -> bool

Control bit to enable the regulator output.

pub const fn set_enable_linreg(&mut self, val: bool)

Control bit to enable the regulator output.

pub const fn enable_bo(&self) -> bool

Control bit to enable the brownout circuitry in the regulator.

pub const fn set_enable_bo(&mut self, val: bool)

Control bit to enable the brownout circuitry in the regulator.

pub const fn enable_ilimit(&self) -> bool

Control bit to enable the current-limit circuitry in the regulator.

pub const fn set_enable_ilimit(&mut self, val: bool)

Control bit to enable the current-limit circuitry in the regulator.

pub const fn enable_pulldown(&self) -> bool

Control bit to enable the pull-down circuitry in the regulator

pub const fn set_enable_pulldown(&mut self, val: bool)

Control bit to enable the pull-down circuitry in the regulator

pub const fn bo_offset(&self) -> u8

Control bits to adjust the regulator brownout offset voltage in 25mV steps

pub const fn set_bo_offset(&mut self, val: u8)

Control bits to adjust the regulator brownout offset voltage in 25mV steps

pub const fn output_trg(&self) -> Reg2p5TogOutputTrg

Control bits to adjust the regulator output voltage

pub const fn set_output_trg(&mut self, val: Reg2p5TogOutputTrg)

Control bits to adjust the regulator output voltage

pub const fn bo_vdd2p5(&self) -> bool

Status bit that signals when a brownout is detected on the regulator output.

pub const fn set_bo_vdd2p5(&mut self, val: bool)

Status bit that signals when a brownout is detected on the regulator output.

pub const fn ok_vdd2p5(&self) -> bool

Status bit that signals when the regulator output is ok. 1 = regulator output > brownout target

pub const fn set_ok_vdd2p5(&mut self, val: bool)

Status bit that signals when the regulator output is ok. 1 = regulator output > brownout target

pub const fn enable_weak_linreg(&self) -> bool

Enables the weak 2p5 regulator

pub const fn set_enable_weak_linreg(&mut self, val: bool)

Enables the weak 2p5 regulator